#!/bin/bash

# Set default umask
umask 022

# Read in the common files
source "${kvm}/functions/common"
source "${kvm}/functions/retry"

# Apply the build stuff
find . -iname "*build_properties" | xargs -I FILE cp FILE .
[ -e "build_properties" ] &&
    source build_properties ||
    fail "Failed to read build_properties. I don't know what I'm doing!"

rm {failed,success} || /bin/true

# Copy the target disk image
disk_orig="${SUITE}-server-cloudimg-${ARCH}-disk1.img"
disk_cp="${disk_orig//cloudimg/cloudimg-vps}"
disk_root="/srv/ec2-images/${SUITE}/${SERIAL:-current}"
disk_working="${WORKSPACE}/${disk_cp}"
raw_f="${WORKSPACE}/raw_f-$(date +%s).img"

cp "${disk_root}/${disk_orig}" "${disk_working}" ||
    fail "Unable to copy ${disk_orig} from ${disk_root}"

# Launch KVM to do the work
${kvm}/launch_kvm.sh \
        --id "${ARCH}-${BUILD_ID}" \
        --mem 1024 \
        --user-data "${kvm}/config/cloud-vps.cfg" \
        --cloud-config "${kvm}/templates/img-vps.tmpl" \
        --extra-disk "${disk_working}" \
        --disk-gb 1 \
        --raw-disk "${raw_f}" \
        --raw-size 1 \
        --img-url /srv/builder/images/precise-builder-latest.img ||
            fail "KVM instance failed to build image."

# Remove the results
rm "${raw_f}" || /bin/true
