#!/bin/bash
#
# Clean up MAASv2 builds
#
my_dir="$(dirname $0)"
my_p_dir="$(dirname $my_dir)"
source ${my_p_dir}/functions/common
source ${my_p_dir}/functions/bzr_check.sh

# Number of builds to publish in the stream
MAX_BUILDS=${MAX_BUILDS:-3}
# Number of days to keep files not referenced in the stream data
REAP_AGE=${REAP_AGE:-2d}

WORKSPACE=${WORKSPACE:-$PWD}
OUTDIR=${JENKINS_HOME:?}/.config/MAASv2_Cleaner/
DAILY_ROOT=/srv/maas-images/ephemeral-v2/daily/
RELEASE_ROOT=/srv/maas-images/ephemeral-v2/releases/
INDEX_PATH=streams/v1/index.json

# Local checkouts
sstreams=${WORKSPACE}/sstreams
maasv2=${WORKSPACE}/maasv2
check_branch ${BZR_SIMPLESTREAMS:-lp:simplestreams} ${sstreams}
check_branch ${BZR_MAASv2:-lp:maas-images} ${maasv2}

#DAILIES
run PYTHONPATH=${sstreams}:${maasv2} \
    ${maasv2}/bin/meph2-util clean-md \
        ${MAX_BUILDS} ${DAILY_ROOT}/${INDEX_PATH}

run PYTHONPATH=${sstreams}:${maasv2} \
    ${maasv2}/bin/meph2-util find-orphans \
        ${OUTDIR}/daily.json \
        ${DAILY_ROOT} ${DAILY_ROOT}/${INDEX_PATH}

run PYTHONPATH=${sstreams}:${maasv2} \
    ${maasv2}/bin/meph2-util reap-orphans \
        --older ${REAP_AGE} \
        ${OUTDIR}/daily.json \
        ${DAILY_ROOT}

# RELEASES
run PYTHONPATH=${sstreams}:${maasv2} \
    ${maasv2}/bin/meph2-util clean-md \
        ${MAX_BUILDS} ${DAILY_ROOT}/${INDEX_PATH}

run PYTHONPATH=${sstreams}:${maasv2} \
    ${maasv2}/bin/meph2-util find-orphans \
        ${OUTDIR}/releases.json \
        ${RELEASE_ROOT} ${RELEASE_ROOT}/${INDEX_PATH}

run PYTHONPATH=${sstreams}:${maasv2} \
    ${maasv2}/bin/meph2-util reap-orphans \
        --older ${REAP_AGE} \
        ${OUTDIR}/releases.json \
        ${RELEASE_ROOT}
