#!/bin/bash

export maas_branch="${MAAS_BRANCH:-http://bazaar.launchpad.net/~smoser/maas/maas.ubuntu.com.images-ephemeral}"

fail() { [ $# -eq 0 ] || echo "$@"; exit 1; }

[ -z "${SERIAL}" ] && fail "Serial must be defined"
[ -z "${SUITE}" ] && fail "Suite must be defined"
[ -z "${MILESTONE}" ] && fail "Milestone must be defined"

cp_d="/srv/maas-images/ephemeral/daily/${SUITE}/${SERIAL}"
finald="/srv/maas-images/ephemeral/releases/${SUITE}"

case "${MILESTONE}" in
    release)    final_d="${finald}/release-${SERIAL}"
    alpha|beta) final_d="${finald}/${milestone}"
esac

# Sanity check
[ ! -e "${cp_d}" ] && fail "Serial ${SERIAL} for ${SUITE} does not exist"
[ -e "${final_d}" ] && fail "Already released ${SERIAL} for ${SUITE} as ${MILESTONE}"

# Make the home directory
mkdir -p "${final_d}" ||
    fail "Unable to create final destination"

# Put the files in final destination
cp -au ${cp_d}/* "${final_d}" ||
    fail "Failed to copy source files for promotion"

# Generate the Query2 tree
src_tree="${WORKSPACE}/maas_src"
bzr branch "${maas_branch}" "${src_tree}"
${src_tree}/tree2query \
    --commit-msg "Build ${BUILD_ID}" \
    --namespace maas \
    /srv/maas-images

# Update the "release" link
if [ "${MILESTONE}" = "release" ]; then
    cur_d="/srv/maas-images/ephemeral/releases/${SUITE}/release"
    [ -e "${cur_d}" ] && rm "${cur_d}"
    ln -s "${final_d}" "${cur_d}" ||
        echo "Failed to update ${cur_d}"
fi

# Sync the stuff
KEY=maas /srv/builder/vmbuilder/bin/trigger-sync
