#!/bin/bash

# set default umask
umask 022

# Read in the common functions
my_dir="$( cd "$( dirname "$0" )" && pwd )"
base_dir=$(dirname ${my_dir})
export PATH="${base_dir}:${my_dir}:${PATH}"
source "${base_dir}/functions/locker"
source "${base_dir}/functions/common"
source "${base_dir}/functions/retry"

dist_ge() { [[ "$1" > "$2" || "$1" == "$2" ]]; }

[ -z "${DISTRO}" -a -n "${SUITE}" ] && DISTRO="${SUITE}"

select_build_config() {
    # Use the latest 12.04 LTS image to do the build.
    local precise_rel_img="http://cloud-images.ubuntu.com/releases/precise/release/ubuntu-12.04-server-cloudimg-amd64-disk1.img"
    local trusty_rel_img="http://cloud-images.ubuntu.com/releases/trusty/release/ubuntu-14.04-server-cloudimg-amd64-uefi1.img"
    local trusty_daily_img="http://cloud-images.ubuntu.com/trusty/current/trusty-server-cloudimg-amd64-uefi1.img"
    local use_trusty=0
    export cloud_init_cfg="cloud-precise.cfg"

    [ -z "${BUILDER_CLOUD_IMAGE}" ] && {
        BUILDER_CLOUD_IMAGE="${precise_rel_img}"

        use_trusty=${USE_TRUSTY:-0}
        dist_ge "${SUITE}" trusty && use_trusty=1
        [[ "${ARCH_TYPE}" =~ (ppc64el|arm) ]] && use_trusty=1
        [ "${use_trusty:-0}" -eq 1 ] &&  {
            echo "Using Trusty to complete this build"
            BUILDER_CLOUD_IMAGE="${trusty_rel_img}"
            export cloud_init_cfg="cloud-trusty.cfg"

            # TEMPORARY until 14.04 is released, but will make sure that when trusty is released
            # that the released images are used
            (curl -I "${BUILDER_CLOUD_IMAGE}" | egrep "HTTP.*200 OK")  || \
                BUILDER_CLOUD_IMAGE="${trusty_daily_img}"
            export BUILDER_CLOUD_IMAGE
        }
    }

    # For ppc64el, we use ppc64el images
    [ "${ARCH_TYPE}" == "ppc64el" ] && {
            export cloud_init_cfg="cloud-trusty-pp64el.cfg"
            BUILDER_CLOUD_IMAGE="${BUILDER_CLOUD_IMAGE//amd64/ppc64el}"
            export BUILDER_CLOUD_IMAGE="${BUILDER_CLOUD_IMAGE//uefi1/disk1}"
        }
    echo "Using ${BUILDER_CLOUD_IMAGE} to do the build"
}
