#!/bin/bash
short_opts="h"
long_opts="distro:,stream:,maas-branch:,out:,template:,serial:,local:,base-name:,out_d:"
getopt_out=$(getopt --name "${0##*/}" \
    --options "${short_opts}" --long "${long_opts}" -- "$@") &&
    eval set -- "${getopt_out}" || { echo "BAD INVOCATION!"; usage; exit 1; }

usage() {
    cat <<EOM
${0##/} - Populated values in build temple.

    Required:
    --distro        Distro code name, i.e. precise
    --template      Template file
    --stream        Stream, i.e. daily, release
    --base-name     The name of the file to work on
    --serial        The build serial
    --out           The output file
    --out_d         Where to stuff the output files

    Optional:
    --maas-branch   bzr branch for maas image code
EOM
}


fail() { echo "${@}" 2>&1; exit 1;}

serial="${serial:-$(date +%Y%m%d)}"
maas_branch="${maas_branch:-http://bazaar.launchpad.net/~smoser/maas/maas.ubuntu.com.images-ephemeral}"
template_f="${PWD}/img-maas.tmpl"

while [ $# -ne 0 ]; do
  cur=${1}; next=${2};
  case "$cur" in
    --distro)                   distro=$2;  shift;;
    --stream)                   stream=$2;  shift;;
    --local)                    local_d=$2; shift;;
    --maas-branch)              maas_branch=$2; shift;;
    --base-name)                base_name=$2; shift;;
    --template)                 template_f=$2; shift;;
    --out)                      out_f=$2; shift;;
    --out_d)                    out_d=$2; shift;;
    --) shift; break;;
  esac
  shift;
done

fail_usage() { fail "Must define $@"; }

[ -z "${distro}" ] && fail_usage "--distro"
[ -z "${stream}" ] && fail_usage "--stream"
[ -z "${local_d}" ] && fail_usage "--local"
[ -z "${out_f}" ] && fail_usage "--out"
[ -z "${out_d}" ] && fail_usage "--out_d"
[ -z "${base_name}" ] && fail_usage "--base-name"

case "$distro" in
   trusty) arches="${ARCH_TYPE:-i386 amd64 armhf}";
           [[ "$(uname -m)" =~ ppc64 ]] && arches="ppc64el";;
   *) arches="${ARCH_TYPE:-i386 amd64 armhf}";;
esac

sed -e "s,%d,${distro},g" \
    -e "s,%S,${stream},g" \
    -e "s,%M,${maas_branch},g" \
    -e "s,%D,${local_d},g" \
    -e "s,%B,${base_name},g" \
    -e "s,%s,${serial},g" \
    -e "s,%O,${out_d},g" \
    -e "s,%A,${arches},g" \
    ${template_f} > ${out_f} ||
        fail "Unable to write template file"

exit 0
