#!/bin/bash

set -eu

API_ROOT="https://atlas.hashicorp.com/api/v1"
BOX_OWNER=${BOX_OWNER:-"ubuntu"}

SUITE="$1"
SERIAL="$2"
ARCH="$3"
IMAGE_TYPE="$4"
ACCESS_TOKEN="$5"

# Always point to the current image, so we don't run in to a problem with
# versions being removed in the future
BOX_URL_PREFIX="http://cloud-images.ubuntu.com/vagrant/${SUITE}/current/${SUITE}-server-cloudimg-${ARCH}"
BOX_URL_POSTFIX="-vagrant-disk1.box"

if [ "${ARCH}" = "amd64" ]; then
    BOX_NAME="${SUITE}64"
elif [ "${ARCH}" = "i386" ]; then
    BOX_NAME="${SUITE}32"
else
    echo "Unknown arch: ${ARCH}"
    exit 1
fi

if [ "${IMAGE_TYPE}" = "juju" ]; then
    BOX_URL="${BOX_URL_PREFIX}-juju${BOX_URL_POSTFIX}"
    BOX_NAME="${BOX_NAME}-juju"
elif [ "${IMAGE_TYPE}" = "default" ]; then
    BOX_URL="${BOX_URL_PREFIX}${BOX_URL_POSTFIX}"
else
    echo "Unknown image type: ${IMAGE_TYPE}"
    exit 1
fi

# Atlas requires versions of the form X.Y.Z where X, Y and Z are all integers
if [[ ${SERIAL} == *"."* ]]; then
    VERSION="${SERIAL}.0"
else
    VERSION="${SERIAL}.0.0"
fi

make_api_call () {
    echo "Making API call:" $@
    curl -f $@ -d "access_token=${ACCESS_TOKEN}" | python -m json.tool
}

echo "Check if the version already registered..."
while true; do
    if curl -f "${API_ROOT}/box/${BOX_OWNER}/${BOX_NAME}/version/${VERSION}"; then
        echo "Version ${VERSION} already registered; trying a higher revision."
        VERSION="$(echo "$VERSION" | awk -F. -v OFS=. '{printf("%s.%s.%s\n", $1, $2, ++$3)}')"
    else
        break
    fi
done
echo "Using version: ${VERSION}"

echo "Create the version..."
make_api_call \
    "${API_ROOT}/box/${BOX_OWNER}/${BOX_NAME}/versions" \
    -X POST \
    -d "version[version]=${VERSION}"
echo "Version created."

echo "Add the virtualbox provider to the version..."
make_api_call \
    "${API_ROOT}/box/${BOX_OWNER}/${BOX_NAME}/version/${VERSION}/providers" \
    -X POST \
    -d "provider[name]=virtualbox" \
    -d "provider[url]=${BOX_URL}"
echo "Virtualbox provider added."

echo "Release the version..."
make_api_call \
    "${API_ROOT}/box/${BOX_OWNER}/${BOX_NAME}/version/${VERSION}/release" \
    -X PUT
echo "Version released."
